"""
Overview
--------

This module contains a collection of tunable models designed for tabular and graph data, including both 
neural network architectures and scikit-learn-based classifiers.

The models are built to handle tasks such as binary classification, multi-class classification.
They offer flexibility in terms of layers, activation functions, regularization 
techniques, and structure, while also supporting hyperparameter optimization through Optuna.

Models available in this module provide a mix of deep learning and traditional machine learning 
techniques. This variety ensures adaptability to a wide range of datasets, giving users 
the choice between powerful neural network architectures and well-established scikit-learn algorithms.

Models features:

- **Flexible Architectures**: Models support various neural network layers, traditional machine 
  learning algorithms, and activation functions.
- **Regularization Techniques**: Options such as dropout, batch normalization, and L2 regularization 
  are available for models where applicable.
- **Wide Range of Applications**: Supports binary classification, multi-class classification making the models highly versatile.
- **Hyperparameter Optimization**: Each model is compatible with Optuna, allowing for 
  automated hyperparameter tuning to maximize model performance.

Models in this module ensure that structured data can be modeled effectively using both deep 
learning and traditional machine learning approaches.
"""
